@@ -27,6 +27,13 @@ def test_writer_config():
 
     writer.Close()
 
+    # Given an invalid file path
+    with pytest.raises(RuntimeError):
+        assert copc.FileWriter(
+            os.path.join(get_data_dir(), "invalid_path", "non_existant_file.copc.laz"),
+            cfg,
+        )
+
     # Custom config
 
     cfg = copc.CopcConfigWriter(8, [2, 3, 4], [-0.02, -0.03, -40.8])
@@ -331,9 +338,35 @@ def test_writer_copy():
 
 def test_writer_copy_and_update():
 
+    # Create test file
+    orig_point_format_id = 7
+    orig_scale = copc.Vector3(0.1, 0.1, 0.1)
+    orig_offset = (10, 10, 10)
+    orig_wkt = "orig_wkt"
+    orig_has_extended_stats = False
+    orig_eb_vlr = copc.EbVlr(1)
+    orig_guid = "orig_guid"
+    orig_spacing = 10.0
+    orig_intensity = 23.5
+
+    orig_cfg = copc.CopcConfigWriter(
+        orig_point_format_id,
+        orig_scale,
+        orig_offset,
+        orig_wkt,
+        orig_eb_vlr,
+        orig_has_extended_stats,
+    )
+
+    writer = copc.FileWriter("orig_test.copc.laz", orig_cfg)
+    writer.copc_config.las_header.guid = orig_guid
+    writer.copc_config.copc_info.spacing = orig_spacing
+    writer.copc_config.copc_extents.intensity.maximum = orig_intensity
+    writer.Close()
+
     file_path = os.path.join(get_data_dir(), "writer_test.copc.laz")
 
-    orig = copc.FileReader(get_autzen_file())
+    orig = copc.FileReader("orig_test.copc.laz")
 
     cfg = orig.copc_config
 
@@ -358,13 +391,17 @@ def test_writer_copy_and_update():
         writer.copc_config.copc_extents.has_extended_stats
         == orig.copc_config.copc_extents.has_extended_stats
     )
+    # Check that other attributes have been copied
+    assert writer.copc_config.copc_info.spacing == orig.copc_config.copc_info.spacing
+    assert writer.copc_config.las_header.guid == orig.copc_config.las_header.guid
+    assert (
+        writer.copc_config.copc_extents.intensity.maximum
+        == orig.copc_config.copc_extents.intensity.maximum
+    )
 
     # Check that we can add a point of new format
-    new_points = copc.Points(
-        new_point_format_id,
-        writer.copc_config.las_header.scale,
-        writer.copc_config.las_header.offset,
-    )
+    new_points = copc.Points(writer.copc_config.las_header)
+
     new_point = new_points.CreatePoint()
     new_point.X = 10
     new_point.Y = 15
@@ -426,6 +463,13 @@ def test_writer_copy_and_update():
         writer.copc_config.copc_extents.has_extended_stats
         == orig.copc_config.copc_extents.has_extended_stats
     )
+    # Check that other attributes have been copied
+    assert writer.copc_config.copc_info.spacing == orig.copc_config.copc_info.spacing
+    assert writer.copc_config.las_header.guid == orig.copc_config.las_header.guid
+    assert (
+        writer.copc_config.copc_extents.intensity.maximum
+        == orig.copc_config.copc_extents.intensity.maximum
+    )
     writer.Close()
 
     reader = copc.FileReader(file_path)
@@ -462,6 +506,13 @@ def test_writer_copy_and_update():
         writer.copc_config.copc_extents.has_extended_stats
         == orig.copc_config.copc_extents.has_extended_stats
     )
+    # Check that other attributes have been copied
+    assert writer.copc_config.copc_info.spacing == orig.copc_config.copc_info.spacing
+    assert writer.copc_config.las_header.guid == orig.copc_config.las_header.guid
+    assert (
+        writer.copc_config.copc_extents.intensity.maximum
+        == orig.copc_config.copc_extents.intensity.maximum
+    )
     writer.Close()
 
     reader = copc.FileReader(file_path)
@@ -498,6 +549,13 @@ def test_writer_copy_and_update():
         writer.copc_config.copc_extents.has_extended_stats
         == orig.copc_config.copc_extents.has_extended_stats
     )
+    # Check that other attributes have been copied
+    assert writer.copc_config.copc_info.spacing == orig.copc_config.copc_info.spacing
+    assert writer.copc_config.las_header.guid == orig.copc_config.las_header.guid
+    assert (
+        writer.copc_config.copc_extents.intensity.maximum
+        == orig.copc_config.copc_extents.intensity.maximum
+    )
     writer.Close()
 
     reader = copc.FileReader(file_path)
@@ -533,6 +591,13 @@ def test_writer_copy_and_update():
         writer.copc_config.copc_extents.has_extended_stats
         == orig.copc_config.copc_extents.has_extended_stats
     )
+    # Check that other attributes have been copied
+    assert writer.copc_config.copc_info.spacing == orig.copc_config.copc_info.spacing
+    assert writer.copc_config.las_header.guid == orig.copc_config.las_header.guid
+    assert (
+        writer.copc_config.copc_extents.intensity.maximum
+        == orig.copc_config.copc_extents.intensity.maximum
+    )
     writer.Close()
 
     reader = copc.FileReader(file_path)
@@ -565,6 +630,13 @@ def test_writer_copy_and_update():
         orig.copc_config.extra_bytes_vlr.items
     )
     assert writer.copc_config.copc_extents.has_extended_stats == new_has_extended_stats
+    # Check that other attributes have been copied
+    assert writer.copc_config.copc_info.spacing == orig.copc_config.copc_info.spacing
+    assert writer.copc_config.las_header.guid == orig.copc_config.las_header.guid
+    assert (
+        writer.copc_config.copc_extents.intensity.maximum
+        == orig.copc_config.copc_extents.intensity.maximum
+    )
     writer.Close()
 
     reader = copc.FileReader(file_path)
@@ -600,6 +672,13 @@ def test_writer_copy_and_update():
     assert writer.copc_config.wkt == new_wkt
     assert len(writer.copc_config.extra_bytes_vlr.items) == len(new_eb_vlr.items)
     assert writer.copc_config.copc_extents.has_extended_stats == new_has_extended_stats
+    # Check that other attributes have been copied
+    assert writer.copc_config.copc_info.spacing == orig.copc_config.copc_info.spacing
+    assert writer.copc_config.las_header.guid == orig.copc_config.las_header.guid
+    assert (
+        writer.copc_config.copc_extents.intensity.maximum
+        == orig.copc_config.copc_extents.intensity.maximum
+    )
     writer.Close()
 
     reader = copc.FileReader(file_path)
@@ -629,13 +708,13 @@ def test_check_spatial_bounds():
 
     point = points.CreatePoint()
     # point has getters/setters for all attributes
-    point.x = 10
-    point.y = 10
-    point.z = 5
+    point.x = 9
+    point.y = 9
+    point.z = 4
 
     points.AddPoint(point)
 
-    writer.AddNode((1, 1, 1, 1), points)
+    writer.AddNode((1, 1, 1, 0), points)
     writer.Close()
 
     reader = copc.FileReader(file_path)
